==> httpsnippet-2.0.16.tgz: package/src/targets/node/axios.js <==
/**
 * @description
 * HTTP code snippet generator for Javascript & Node.js using Axios.
 *
 * @author
 * @rohit-gohri
 *
 * for any questions or issues regarding the generated code snippet, please open an issue mentioning the author.
 */
'use strict'

const util = require('util')
const stringifyObject = require('stringify-object')
const CodeBuilder = require('../../helpers/code-builder')
const { removeProperty, checkIfRequestContainsFile } = require('../../helpers/general')
const { constructAppendedParamsCode } = require('../../helpers/params')

module.exports = function (source, options) {
  const opts = Object.assign({
    indent: '  '
  }, options)
  
  let code = new CodeBuilder(opts.indent)

  if (checkIfRequestContainsFile(source)) {
    code.push('const fs = require("fs");')
  }

  code.push('const axios = require("axios");')

  const reqOpts = {
    method: source.method,
    url: source.url
  }

  if (Object.keys(source.queryObj).length) {
    reqOpts.params = source.queryObj
  }

  if (Object.keys(source.allHeaders).length) {
    reqOpts.headers = source.allHeaders
  }

  switch (source.postData.mimeType) {
    case 'application/json': {
      if (source.postData.jsonObj) {
        reqOpts.data = JSON.stringify(source.postData.jsonObj)
      }
      break
    }

    case 'application/x-www-form-urlencoded': {
      code.blank()
        .push('const encodedParams = new URLSearchParams();')
      code = constructAppendedParamsCode(code, source.postData.params, { isBrowser: false, dataVarName: 'encodedParams' })

      reqOpts.data = 'encodedParams'
      break
    }
      
    case 'multipart/form-data': {
      // content-type header will come from the data.getHeaders() with the right boundary
      reqOpts.headers = removeProperty(reqOpts.headers, 'content-type') 
      reqOpts.headers.placeholderGetHeaders = 'placeholderGetHeaders'

      code.unshift('const FormData = require("form-data");')
        .blank()
        .push('const data = new FormData();')
      code = constructAppendedParamsCode(code, source.postData.params, { isBrowser: false, dataVarName: 'data' })

      reqOpts.data = 'data'
      break
    }

    default: {
      if (source.postData.text) {
        reqOpts.data = source.postData.text
      }
    }
  }

  code.blank()
    .push('const options = %s;', stringifyObject(reqOpts, { indent: '  ', inlineCharacterLimit: 80 })
      .replace(/'encodedParams'/, 'encodedParams').replace(/'data'/, 'data')
      .replace("placeholderGetHeaders: 'placeholderGetHeaders'", '...data.getHeaders()'))
    .blank()

  code.push(util.format('axios.request(options).then(%s', 'function (response) {'))
    .push(1, 'console.log(response.data);')
    .push('}).catch(%s', 'function (error) {')
    .push(1, 'console.error(error);')
    .push('});')

  return code.join()
}

module.exports.info = {
  key: 'axios',
  title: 'Axios',
  link: 'https://github.com/axios/axios',
  description: 'Promise based HTTP client for the browser and node.js'
}

==> httpsnippet-2.1.6.tgz: package/src/targets/node/axios.js <==
/**
 * @description
 * HTTP code snippet generator for Javascript & Node.js using Axios.
 *
 * @author
 * @rohit-gohri
 *
 * for any questions or issues regarding the generated code snippet, please open an issue mentioning the author.
 */
'use strict'

const util = require('util')
const stringifyObject = require('../../helpers/stringify-js-object')
const CodeBuilder = require('../../helpers/code-builder')

module.exports = function (source, options) {
  const opts = Object.assign({
    indent: '  '
  }, options)

  const code = new CodeBuilder(opts.indent)

  code.push('var axios = require("axios").default;')
    .blank()

  const reqOpts = {
    method: source.method,
    url: source.url
  }

  if (Object.keys(source.queryObj).length) {
    reqOpts.params = source.queryObj
  }

  if (Object.keys(source.allHeaders).length) {
    reqOpts.headers = source.allHeaders
  }

  switch (source.postData.mimeType) {
    case 'application/x-www-form-urlencoded':
      reqOpts.data = source.postData.paramsObj
      break

    case 'application/json':
      if (source.postData.jsonObj) {
        reqOpts.data = source.postData.jsonObj
      }
      break

    default:
      if (source.postData.text) {
        reqOpts.data = source.postData.text
      }
  }

  code.push('var options = %s;', stringifyObject(reqOpts, { indent: '  ', inlineCharacterLimit: 80 }))
    .blank()

  code.push(util.format('axios.request(options).then(%s', 'function (response) {'))
    .push(1, 'console.log(response.data);')
    .push('}).catch(%s', 'function (error) {')
    .push(1, 'console.error(error);')
    .push('});')

  return code.join()
}

module.exports.info = {
  key: 'axios',
  title: 'Axios',
  link: 'https://github.com/axios/axios',
  description: 'Promise based HTTP client for the browser and node.js'
}
